Install — Riskfolio-Lib 0.1 documentation

# Install

## Mac OS X, Windows, and Linux

Riskfolio-lib only supports Python 3 on OS X, Windows, and Linux. I recommend using pip for installation.

1. (Windows only) Download the Visual Studio build tools for Python 3 (download).

2. Install `Riskfolio-lib`.

>     pip install riskfolio-lib

## Dependencies

Riskfolio-Lib has the following dependencies:

- numpy>=1.17.0

- scipy>=1.1.0

- pandas>=1.0.0

- matplotlib>=3.0.0

- cvxpy>=1.0.25

- scikit-learn>=0.22.0

- statsmodels>=0.10.1